@@ -614,10 +614,12 @@ size_t gatherLocalAddresses(union sockaddr_union** addressArray)
    union sockaddr_union anyAddress;
    size_t               addresses = 0;
    int                  sd;
+   const bool           hasIPv6   = checkIPv6();
 
-   string2address(checkIPv6() ? "[::]" : "0.0.0.0", &anyAddress);
-   sd = ext_socket(checkIPv6() ? AF_INET6 : AF_INET, SOCK_SEQPACKET, IPPROTO_SCTP);
+   string2address(hasIPv6 ? "[::]" : "0.0.0.0", &anyAddress);
+   sd = ext_socket(hasIPv6 ? AF_INET6 : AF_INET, SOCK_SEQPACKET, IPPROTO_SCTP);
    if(sd >= 0) {
+      setIPv6Only(sd, 0);
       if(ext_bind(sd, (struct sockaddr*)&anyAddress, getSocklen(&anyAddress.sa)) == 0) {
          addresses = getAddressesFromSocket(sd, addressArray);
       }
@@ -1833,6 +1835,18 @@ bool setReusable(int sd, int on)
 }
 
 
+/* ###### Set IPV6_V6ONLY (if supported) ################################# */
+bool setIPv6Only(int sd, int on)
+{
+#ifdef IPV6_V6ONLY
+   if(ext_setsockopt(sd, IPPROTO_IPV6, IPV6_V6ONLY, &on, sizeof(on)) < 0) {
+      return(false);
+   }
+#endif
+   return(true);
+}
+
+
 /* ###### Establish connection ########################################### */
 int connectplus(int                   sockfd,
                 union sockaddr_union* addressArray,
