@@ -110,11 +110,14 @@ int rsp_socket_internal(int domain, int type, int protocol, int customFD)
    domain = (domain == 0) ? (checkIPv6() ? AF_INET6 : AF_INET) : domain;
    if(customFD < 0) {
       fd = ext_socket(domain, type, protocol);
+      if( (fd >= 0) && (domain == AF_INET6) ) {
+         setIPv6Only(fd, 0);
+      }
    }
    else {
       fd = customFD;
    }
-   if(fd <= 0) {
+   if(fd < 0) {
       LOG_ERROR
       logerror("Unable to create socket for RSerPool socket");
       LOG_END
@@ -849,6 +852,7 @@ static int connectToPE(struct RSerPoolSocket* rserpoolSocket,
                    rserpoolSocket->SocketProtocol);
    if(sd >= 0) {
       setNonBlocking(sd);
+      setIPv6Only(sd, false);
       if(configureSCTPSocket(rserpoolSocket, sd, 0)) {
          LOG_VERBOSE
          fprintf(stdlog, "Trying connection to pool element $%08x (", rserpoolSocket->ConnectedSession->ConnectedPE);
@@ -860,7 +864,7 @@ static int connectToPE(struct RSerPoolSocket* rserpoolSocket,
          LOG_END
 
          result = sctp_connectx(sd, (struct sockaddr*)destinationAddressArray, destinationAddresses, NULL);
-         if((result == 0) || (errno == EINPROGRESS)) {
+         if((result >= 0) || (errno == EINPROGRESS) || (errno == EISCONN)) {
             ufds.fd     = sd;
             ufds.events = POLLIN;
             if(ext_poll(&ufds, 1, (int)(rserpoolSocket->ConnectedSession->ConnectTimeout / 1000)) > 0) {
